@@ -22,18 +22,19 @@ def mobile_template(template):
     different template.
 
     """
+
     def decorator(f):
         @functools.wraps(f)
         def wrapper(*args, **kwargs):
             ctx = stack.top
-            if ctx is not None and hasattr(ctx, 'request'):
+            if ctx is not None and hasattr(ctx, "request"):
                 request = ctx.request
-                is_mobile = getattr(request, 'MOBILE', None)
-                kwargs['template'] = re.sub(r'{(.+?)}',
-                                            r'\1' if is_mobile else '',
-                                            template)
+                is_mobile = getattr(request, "MOBILE", None)
+                kwargs["template"] = re.sub(r"{(.+?)}", r"\1" if is_mobile else "", template)
             return f(*args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
@@ -56,14 +57,17 @@ def mobilized(normal_fn):
     function based on ``request.MOBILE``.
 
     """
+
     def decorator(mobile_fn):
         @functools.wraps(mobile_fn)
         def wrapper(*args, **kwargs):
             ctx = stack.top
-            if ctx is not None and hasattr(ctx, 'request'):
+            if ctx is not None and hasattr(ctx, "request"):
                 request = ctx.request
                 if not request.MOBILE:
                     return normal_fn(*args, **kwargs)
             return mobile_fn(*args, **kwargs)
+
         return wrapper
+
     return decorator
